#!/usr/bin/env -S python #
# -*- coding: utf-8 -*-

"""
The purpose of this file is to make the contents of the neighboring `python`
subdirectory available to your Python interpreter (i.e. listed on its
`sys.path`) in any future Python session.

The recommended way to use this file is to open a command prompt, working
in the directory where this `setup.py` file is located, and do::

    python -m pip install -e .

The "editable" flag `-e` causes Python's setuptools to simply store a link
to the present location of the subdirectory. The advantage of an editable
installation is that you still have only one definitive copy of the code
(possibly under version control) and any update to those files will then be
adopted automatically following a new Python launch.

You could remove the `-e` flag if you want setuptools to make a static
*copy* of the code, within the `site-packages` of your Python distribution
or of your virtual environment. This is the usual/expected way of using
`pip`, but it means you give up the advantage of automatic updating
mentioned above.
"""

import os
import sys
import inspect
import setuptools

package_dir = 'python' # the directory that would get added to the path, expressed relative to the location of this setup.py file

try: __file__
except:
	try: frame = inspect.currentframe(); __file__ = inspect.getfile( frame )
	finally: del frame  # https://docs.python.org/3/library/inspect.html#the-interpreter-stack
HERE = os.path.realpath( os.path.dirname( __file__ ) )

properties = dict(
	line.strip().split( '=', 1 )
	for line in open( os.path.join( HERE, 'library.properties' ) )
	if line.strip()
)

# import the package itself - but make sure it's the to-be-installed version and not some legacy version hanging over
sys.path.insert( 0, os.path.realpath( os.path.join( HERE, package_dir ) ) )
import keyhole  # could use this to get the __version__ etc
sys.path.pop( 0 )

assert keyhole.__version__ == properties[ 'version' ]

setup_args = dict(
	name='keyhole-comm',
	package_dir={ '' : package_dir },
	packages=[ 'Keyhole' ],
	install_requires=[ 'pyserial' ],
	
	version = properties[ 'version' ],	
	description = 'Python counterpart to the Keyhole library for the Arduino IDE',
	long_description = """\
Allows easy communication over a serial port with microcontrollers,
particularly ones programmed using the Keyhole library.
""",
	long_description_content_type='text/rst',
	license = "BSD",
	author = properties[ 'author' ].split( '<', 1 )[ 0 ].strip(),
	author_email = properties[ 'author' ].split( '<', 1 )[ 1 ].strip( '\t <>' ),
	url = properties[ 'url' ],
)

if __name__ == '__main__' and getattr( sys, 'argv', [] )[ 1: ]:
	setuptools.setup( **setup_args )
else:
	sys.stderr.write( """
The setup.py file should not be run or imported directly.
Instead, it is used as follows::

    python -m pip install -e  "%s"

""" % HERE )

